django\_sorcery.views package
=============================

.. automodule:: django_sorcery.views
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   django_sorcery.views.base
   django_sorcery.views.detail
   django_sorcery.views.edit
   django_sorcery.views.list
